@@ -50,6 +50,7 @@ class DatabaseSettings(BaseModel):
 
     path: str = "/var/db/faddr/"
     name: str = "faddr-db.sqlite"
+    revisions: int = 10
 
 
 class RancidDirSettings(BaseModel):
@@ -74,6 +75,7 @@ class FaddrSettings(BaseSettings):
     """Faddr settings root."""
 
     debug: bool = False
+    processes: int = 1
     templates_dir: Path = Path(__file__).parent.joinpath("templates")
     database: DatabaseSettings = DatabaseSettings()
     rancid: RancidSettings = RancidSettings()
